@@ -247,7 +247,7 @@ static void draw_herring_count( int herring_count )
     glPushMatrix(); {
     
         glTranslatef(getparam_x_resolution() - HERRING_ICON_X_OFFSET + HERRING_ICON_WIDTH, 
-                     HERRING_Y_OFFSET,
+                     getparam_y_resolution() - HERRING_Y_OFFSET,
                      0 );
         
         draw_string( font, string );
