@@ -40,7 +40,6 @@
 #include "ui_snow.h"
 #include "joystick.h"
 #include "hud_training.h"
-//MV#import "sharedGeneralFunctions.h"
 
 #define SCREEN_WIDTH 800
 #define SCREEN_HEIGHT 480
@@ -505,15 +504,6 @@ static void start_click_cb( button_t *button, void *userdata )
     
     update_race_data();
     
-#ifdef __APPLE__
-    //set landscape resolution
-    setparam_x_resolution(800); //MV
-    setparam_y_resolution(480); //MV
-    
-    //rotate screen
-    //MV turnScreenToLandscape();
-#endif
-    
     //Select the starting step
     if (!strcmp(g_game.race.name,"Basic tutorial")) init_starting_tutorial_step(0);
     if (!strcmp(g_game.race.name,"Jump tutorial")) init_starting_tutorial_step(10);
@@ -657,7 +647,7 @@ static void set_widget_positions_and_draw_decorations()
     box_width = 300;
     box_height = 310;
     box_max_y = h - 128;
-    x_org = 10;
+    x_org = 150;
     y_org = h/2 - box_height/2;
     
     if ( y_org + box_height > box_max_y ) {
@@ -683,7 +673,7 @@ static void set_widget_positions_and_draw_decorations()
                                       y_org + 235 ) );
     textarea_set_position( 
                           desc_ta,
-                          make_point2d( x_org + w - textarea_get_width(desc_ta) - 10,
+                          make_point2d( x_org + w - textarea_get_width(desc_ta) - x_org,
                                        y_org + 26));
     if ( g_game.practicing || 
         ( cup_complete &&
@@ -957,7 +947,7 @@ static void race_select_init(void)
      * Create text area 
      */
     desc_ta = textarea_create( dummy_pos,
-                              170, 147,
+                              2*170, 147, //MV 170 147
                               "race_description",
                               "" );
     
