@@ -66,6 +66,7 @@ static bool_t trick_modifier;
 static bool_t paddling;
 static bool_t charging;
 static bool_t braking;
+static bool_t use_keyboard;
 static scalar_t charge_start_time;
 static int last_terrain;
 
@@ -112,6 +113,7 @@ void racing_init(void)
     left_turn = right_turn = paddling = False;
     trick_modifier = False;
     charging = False;
+    use_keyboard = False;
     plyr->control.turn_fact = 0.0;
     plyr->control.turn_animation = 0.0;
     plyr->control.is_braking = False;
@@ -303,6 +305,7 @@ void racing_loop( scalar_t time_step )
     else
         trick_modifier = False;
     
+    if (!use_keyboard) {
     /*left_turn and right_turn are informations useful for tricks*/
     if (iPhone_turn_fact>TURN_FACTOR_LIMIT) {
         left_turn=false;
@@ -313,9 +316,9 @@ void racing_loop( scalar_t time_step )
         right_turn=false;
     } else left_turn = right_turn = false;
     
-    plyr->control.turn_fact = iPhone_turn_fact;
-    plyr->control.turn_animation = iPhone_turn_fact;
-
+        plyr->control.turn_fact = iPhone_turn_fact;
+        plyr->control.turn_animation = iPhone_turn_fact;
+    }
     
     /*
      * Paddling
@@ -515,6 +518,7 @@ END_KEYBOARD_CB
 START_KEYBOARD_CB( turn_left_cb )
 {
     left_turn = (bool_t) !release;
+    use_keyboard = True;
 }
 END_KEYBOARD_CB
 
@@ -522,6 +526,7 @@ END_KEYBOARD_CB
 START_KEYBOARD_CB( turn_right_cb )
 {
     right_turn = (bool_t) !release;
+    use_keyboard = True;
 }
 END_KEYBOARD_CB
 
