@@ -41,7 +41,7 @@ struct char_dims {
     unsigned char h;
     signed char x_offset;
     signed char y_offset;
-    char kern_width;
+    signed char kern_width;
     short x_pixel;
     short y_pixel;
 };
