@@ -20,12 +20,13 @@
 #include "tuxracer.h"
 #include "winsys.h"
 #include "audio.h"
-#include <SDL_gles.h>
+#include <libosso.h>
 
 /* Windowing System Abstraction Layer */
 /* Abstracts creation of windows, handling of events, etc. */
 
 #if defined( HAVE_SDL )
+#include <SDL_gles.h>
 static SDL_GLES_Context *context;
 #if defined( HAVE_SDL_MIXER )
 #   include "SDL_mixer.h"
@@ -37,6 +38,8 @@ static SDL_GLES_Context *context;
 /*---------------------------------------------------------------------------*/
 /*---------------------------------------------------------------------------*/
 
+Uint32 winsys_display_blank_event(Uint32 interval, void *param);
+
 static SDL_Surface *screen = NULL;
 
 static winsys_display_func_t display_func = NULL;
@@ -50,6 +53,7 @@ static winsys_atexit_func_t atexit_func = NULL;
 
 static bool_t redisplay = False;
 
+osso_context_t *osso_context;
 
 /*---------------------------------------------------------------------------*/
 /*! 
@@ -254,7 +258,7 @@ static void setup_sdl_video_mode()
 void winsys_init( int *argc, char **argv, char *window_title, 
 		  char *icon_title )
 {
-    Uint32 sdl_flags = SDL_INIT_VIDEO | SDL_INIT_NOPARACHUTE;
+    Uint32 sdl_flags = SDL_INIT_VIDEO | SDL_INIT_NOPARACHUTE | SDL_INIT_TIMER;
 
     /*
      * Initialize SDL
@@ -263,11 +267,11 @@ void winsys_init( int *argc, char **argv, char *window_title,
 	handle_error( 1, "Couldn't initialize SDL: %s", SDL_GetError() );
     }
 
+    osso_context = osso_initialize("tuxrace", "0.1", TRUE, NULL);
 
     /* 
      * Init video 
      */
-    //MV SDL_GL_SetAttribute( SDL_GL_DOUBLEBUFFER, 1 );
 
 #if defined( USE_STENCIL_BUFFER )
     SDL_GLES_SetAttribute( SDL_GLES_STENCIL_SIZE, 8 ); 
@@ -277,6 +281,8 @@ void winsys_init( int *argc, char **argv, char *window_title,
 
     SDL_WM_SetCaption( window_title, icon_title );
 
+    SDL_AddTimer(20000, winsys_display_blank_event, NULL);
+
 }
 
 
@@ -406,7 +412,26 @@ void winsys_process_events()
 		}
 		
 		break;
-	    }
+
+	    case SDL_USEREVENT:
+		osso_display_blanking_pause( osso_context );
+		break;
+
+	    case SDL_QUIT:
+		winsys_exit(0);
+		break;
+
+/*            case SDL_ACTIVEEVENT:
+		if ( event.active.gain == 0) {
+			Mix_PauseMusic();
+			while (SDL_WaitEvent(&event) ) {
+				if (event.type == SDL_QUIT) return;
+				if (event.type == SDL_ACTIVEEVENT && event.active.gain == 1 ) break;
+			}
+		}
+		Mix_ResumeMusic();
+		break;
+*/	}
 
 	    SDL_LockAudio();
 	    SDL_UnlockAudio();
@@ -429,6 +454,22 @@ void winsys_process_events()
     code_not_reached();
 }
 
+Uint32 winsys_display_blank_event(Uint32 interval, void *param)
+{
+       SDL_Event event;
+       SDL_UserEvent userevent;
+
+       userevent.type = SDL_USEREVENT;
+       userevent.code = 0;
+       userevent.data1 = NULL;
+       userevent.data2 = NULL;
+
+       event.type = SDL_USEREVENT;
+       event.user = userevent;
+
+       SDL_PushEvent(&event);
+       return(interval);
+}
 
 /*---------------------------------------------------------------------------*/
 /*! 
